# Changelog
All notable changes will be documented in this file. The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

## 0.1.1 - 2019-01-18
### Added
- Can now be installed easily via `pip`. Directory structure has been modified as a result.

## 0.1.0 - 2019-01-09
### Added
- First release of pyne2001